@@ -63,7 +63,7 @@ _LEVEL_TO_FORMAT_MAPPING = {
 _UD_CATEGORIES = {
     cat: name
     for name, cat in ud.__dict__.items()
-    if isinstance(cat, int) and name not in ('FLUSH', 'NO_FLUSH', 'FUNCTION', 'NO_FUNCTION', 'ALL', 'INFO', 'PROCESS', 'WARN', 'ERROR') and name.isupper()
+    if isinstance(cat, int) and name not in ('FLUSH', 'NO_FLUSH', 'FUNCTION', 'NO_FUNCTION', 'ALL', 'INFO', 'PROCESS', 'WARN', 'ERROR', 'DEBUG', 'WARNING') and name.isupper()
 }
 
 
@@ -224,7 +224,7 @@ def basicConfig(
     univention_debug_categories=None,
     do_exit=True,
     delay_init=False,  # until first use
-    use_structured_logging=False,
+    use_structured_logging=True,
     **kwargs,
 ):
     """
@@ -276,14 +276,14 @@ class SyslogPrefix(logging.Filter):
         """
         Syslog priorities:
 
-           <0>: Emergency
-           <1>: Alert
-           <2>: Critical
-           <3>: Error
-           <4>: Warning
-           <5>: Notice
-           <6>: Info
-           <7>: Debug
+            <0>: Emergency
+            <1>: Alert
+            <2>: Critical
+            <3>: Error
+            <4>: Warning
+            <5>: Notice
+            <6>: Info
+            <7>: Debug
         """
         if level >= logging.CRITICAL:
             return 2
@@ -307,7 +307,7 @@ class StructuredFormatter(logging.Formatter):
 
     Producing log lines like:
 
-       2025-01-01T00:00:00.000000+00:00 INFO    [         -] module.function:1 the message\t| pid=12345 logname=ADMIN
+        2025-01-01T00:00:00.000000+00:00 INFO    [         -] module.function:1 the message\t| pid=12345 logname=ADMIN
     """
 
     def __init__(
@@ -335,7 +335,7 @@ class StructuredFormatter(logging.Formatter):
             keys=data_fields or ['pid', 'umcmodule', 'logname', 'func'],
             mapping=data_mapping or {'at': 'levelname', 'pid': 'process', 'time': 'asctime', 'logname': 'name'},
             defaults={'func': '{module}.{funcName}:{lineno}'} | (data_defaults or {}),
-            ignored_keys=data_ignored_keys or ['msg', 'request_id', 'syslog_priority'],  # 'stack_info', 'exc_info'
+            ignored_keys=data_ignored_keys or ['msg', 'request_id', 'syslog_priority', 'logfmt'],  # 'stack_info', 'exc_info'
             datefmt=_datefmt,
         )
         super().__init__(fmt=fmt, datefmt=_datefmt, defaults={'request_id': '-', key: '', 'syslog_priority': ''} | (defaults or {}), style=style)
@@ -552,7 +552,7 @@ class LevelDependentFormatter(logging.Formatter):
 
     .. deprecated:: 5.2-3
 
-       unstructured logging with different formats will be removed in UCS 5.2-5.
+        unstructured logging with different formats will be removed in UCS 5.2-5.
     """
 
     RESERVED = (*RESERVED, 'prefix', 'request_id', 'pid', 'umcmodule')
