@@ -9,9 +9,7 @@
 #include <Python.h>
 #include <univention/debug.h>
 
-#if PY_MAJOR_VERSION >= 3
 #define PyInt_FromLong PyLong_FromLong
-#endif
 
 /*
  * example:
@@ -43,7 +41,7 @@ PyDoc_STRVAR(py_univention_debug_debug__doc__,
         "\n"
         "Log message 'message' of severity 'level' to facility 'category'.\n"
         "category - ID of the category, e.g. MAIN, LDAP, USERS, ...\n"
-        "level - Level of logging, e.g. ERROR, WARN, PROCESS, INFO, ALL\n"
+        "level - Level of logging, e.g. ERROR, WARNING, PROCESS, INFO, DEBUG\n"
         "message - The message to log");
 
 static PyObject *
@@ -74,12 +72,8 @@ py_univention_debug_init(PyObject *self, PyObject *args)
         Py_RETURN_NONE;
     }
 
-#if PY_MAJOR_VERSION >= 3
     /* use "w+" instead of "a+" as Python3 handels O_APPEND internally by using lseek(), which breaks on STDOUT and STDERR */
     file = PyFile_FromFd(/*fd*/fileno(fd), /*name*/logfile, /*mode*/"wb+", /*buffering*/0, /*encoding*/NULL, /*errors*/NULL, /*newline*/NULL, /*closefd*/0);
-#else
-    file = PyFile_FromFile( fd, logfile, "a+", NULL );
-#endif
 
     return file;
 }
@@ -111,7 +105,7 @@ PyDoc_STRVAR(py_univention_debug_set_level__doc__,
         "\n"
         "Set minimum required severity 'level' for facility 'category'.\n"
         "category - ID of the category, e.g. MAIN, LDAP, USERS, ...\n"
-        "level - Level of logging, e.g. ERROR, WARN, PROCESS, INFO, ALL");
+        "level - Level of logging, e.g. ERROR, WARNING, PROCESS, INFO, DEBUG");
 
 static PyObject *
 py_univention_debug_get_level(PyObject *self, PyObject *args)
@@ -247,7 +241,6 @@ static struct PyMethodDef debug_methods[] = {
     { NULL, NULL, 0, NULL}
 };
 
-#if PY_MAJOR_VERSION >= 3
 PyDoc_STRVAR(m_doc,
         "univention._debug module");
 static struct PyModuleDef moduledef = {
@@ -256,27 +249,19 @@ static struct PyModuleDef moduledef = {
     .m_doc = m_doc,
     .m_methods = debug_methods,
 };
-#endif
 
 
-#if PY_MAJOR_VERSION >= 3
 PyMODINIT_FUNC PyInit__debug(void)
-#else
-PyMODINIT_FUNC init_debug(void)
-#endif
 {
     PyObject *module, *dict;
 
-#if PY_MAJOR_VERSION >= 3
     module = PyModule_Create(&moduledef);
-#else
-    module = Py_InitModule("univention._debug", debug_methods);
-#endif
 
     dict = PyModule_GetDict(module);
 
     PyDict_SetItemString(dict, "ERROR", PyInt_FromLong(UV_DEBUG_ERROR));
     PyDict_SetItemString(dict, "WARN", PyInt_FromLong(UV_DEBUG_WARN));
+    PyDict_SetItemString(dict, "WARNING", PyInt_FromLong(UV_DEBUG_WARN));
     PyDict_SetItemString(dict, "PROCESS", PyInt_FromLong(UV_DEBUG_PROCESS));
     PyDict_SetItemString(dict, "INFO", PyInt_FromLong(UV_DEBUG_INFO));
     PyDict_SetItemString(dict, "ALL", PyInt_FromLong(UV_DEBUG_ALL));
@@ -312,9 +297,7 @@ PyMODINIT_FUNC init_debug(void)
     PyDict_SetItemString(dict, "NO_FUNCTION", PyInt_FromLong(UV_DEBUG_NO_FUNCTION));
     PyDict_SetItemString(dict, "FUNCTION", PyInt_FromLong(UV_DEBUG_FUNCTION));
 
-#if PY_MAJOR_VERSION >= 3
     return module;
-#endif
 }
 
 /* vim:set ts=4 sw=4 et: */
